﻿Imports System.IO

Public Class Form1

    Private WithEvents refreshTimer As New Timer()
    Private notifiedDrives As New HashSet(Of String)() ' To keep track of notified drives
    Private driveIcons As New ImageList()

    ' User-configurable settings
    Private refreshInterval As Integer = 60000 ' Default 60 seconds
    Private lowSpaceThreshold As Long = 10 * 1024& * 1024 * 1024 ' Default 10 GB

    Private Sub Form1_Load(sender As Object, e As EventArgs) Handles MyBase.Load
        LoadSettings() ' Load settings here

        ' Initialize ImageList with icons
        driveIcons.ImageSize = New Size(16, 16) ' Example size; adjust as needed
        driveIcons.Images.Add("normal", My.Resources.NormalDriveIcon) ' Load a normal drive icon
        driveIcons.Images.Add("low", My.Resources.LowSpaceDriveIcon) ' Load a low space drive icon

        ' Assign ImageList to ListView
        ListView1.SmallImageList = driveIcons

        ' Set the columns for the ListView
        ListView1.Columns.Add("Drive", 100)
        ListView1.Columns.Add("Total Size", 100)
        ListView1.Columns.Add("Available Space", 100)

        ListView1.Columns(0).AutoResize(ColumnHeaderAutoResizeStyle.HeaderSize)
        ListView1.Columns(1).AutoResize(ColumnHeaderAutoResizeStyle.HeaderSize)
        ListView1.Columns(2).AutoResize(ColumnHeaderAutoResizeStyle.HeaderSize)

        refreshTimer.Interval = refreshInterval
        refreshTimer.Start()

        ' Refresh the drive information
        LoadDriveInformation()
    End Sub

    Private Sub LoadSettings()
        If File.Exists("settings.txt") Then
            Dim settings As String() = File.ReadAllLines("settings.txt")
            If settings.Length >= 2 Then
                refreshInterval = Integer.Parse(settings(0))
                lowSpaceThreshold = Long.Parse(settings(1)) * 1024 * 1024 * 1024 ' Convert GB to bytes
            End If
        End If
    End Sub

    Private Sub refreshTimer_Tick(sender As Object, e As EventArgs) Handles refreshTimer.Tick
        LoadDriveInformation()
    End Sub

    Private Sub LoadDriveInformation()
        Try
            ' Clear previous items
            ListView1.Items.Clear()

            ' Get all drives
            Dim drives As DriveInfo() = DriveInfo.GetDrives()

            For Each drive As DriveInfo In drives
                If drive.IsReady Then
                    Dim totalSize As Long = drive.TotalSize
                    Dim availableSpace As Long = drive.AvailableFreeSpace
                    Dim driveName As String = drive.Name

                    ' Create a ListView item
                    Dim item As New ListViewItem(driveName)
                    item.SubItems.Add(FormatBytes(totalSize))
                    item.SubItems.Add(FormatBytes(availableSpace))

                    ' Check if the available space is below the threshold
                    If availableSpace < LowSpaceThreshold Then
                        item.ForeColor = Color.Red ' Change text color to red
                        item.ImageKey = "low" ' Set icon for low space
                        ' Check if we've already notified for this drive
                        If Not notifiedDrives.Contains(driveName) Then
                            ' Show a MessageBox alert
                            MessageBox.Show($"Warning: Drive {driveName} has low space! Available space: {FormatBytes(availableSpace)}", "Low Disk Space Alert", MessageBoxButtons.OK, MessageBoxIcon.Warning)
                            notifiedDrives.Add(driveName) ' Mark this drive as notified
                        End If
                    Else
                        item.ForeColor = Color.Black ' Set default text color
                        item.ImageKey = "normal" ' Set icon for normal state
                        notifiedDrives.Remove(driveName) ' Remove from notified if space is adequate
                    End If

                    ' Add the item to the ListView
                    ListView1.Items.Add(item)
                End If
            Next
        Catch ex As Exception
            MessageBox.Show("Error loading drive information: " & ex.Message)
        End Try
    End Sub

    Private Function FormatBytes(ByVal bytes As Long) As String
        Dim suffixes As String() = {"B", "KB", "MB", "GB", "TB"}
        Dim i As Integer = 0

        While bytes >= 1024 AndAlso i < suffixes.Length - 1
            bytes /= 1024
            i += 1
        End While

        Return $"{bytes} {suffixes(i)}"
    End Function

    Private Sub btnSettings_Click(sender As Object, e As EventArgs) Handles btnSettings.Click
        Dim settingsForm As New SettingsForm()
        settingsForm.RefreshInterval = refreshInterval
        settingsForm.LowSpaceThreshold = lowSpaceThreshold

        If settingsForm.ShowDialog() = DialogResult.OK Then
            refreshInterval = settingsForm.RefreshInterval
            lowSpaceThreshold = settingsForm.LowSpaceThreshold
            refreshTimer.Interval = refreshInterval ' Update the timer interval
            LoadDriveInformation()
        End If
    End Sub

    Private Sub btnExport_Click(sender As Object, e As EventArgs) Handles btnExport.Click
        Dim saveFileDialog As New SaveFileDialog()
        saveFileDialog.Filter = "CSV files (*.csv)|*.csv|All files (*.*)|*.*"
        saveFileDialog.Title = "Save Drive Report"
        If saveFileDialog.ShowDialog() = DialogResult.OK Then
            ExportDriveReport(saveFileDialog.FileName)
        End If
    End Sub

    Private Sub ExportDriveReport(filePath As String)
        Try
            Using writer As New StreamWriter(filePath)
                ' Write header
                writer.WriteLine("Drive,Total Size (GB),Available Space (GB)")

                For Each item As ListViewItem In ListView1.Items
                    Dim driveName As String = item.Text
                    Dim totalSize As Long = Convert.ToInt64(item.SubItems(1).Text.Split(" "c)(0)) * If(item.SubItems(1).Text.Contains("GB"), 1024 * 1024 * 1024, If(item.SubItems(1).Text.Contains("MB"), 1024 * 1024, 1))
                    Dim availableSpace As Long = Convert.ToInt64(item.SubItems(2).Text.Split(" "c)(0)) * If(item.SubItems(2).Text.Contains("GB"), 1024 * 1024 * 1024, If(item.SubItems(2).Text.Contains("MB"), 1024 * 1024, 1))

                    ' Convert to GB
                    Dim totalSizeInGB As Decimal = totalSize / (1024 * 1024 * 1024)
                    Dim availableSpaceInGB As Decimal = availableSpace / (1024 * 1024 * 1024)

                    ' Write data line
                    writer.WriteLine($"{driveName},{totalSizeInGB:F2},{availableSpaceInGB:F2}")
                Next
            End Using
            MessageBox.Show("Drive report exported successfully!", "Export Successful", MessageBoxButtons.OK, MessageBoxIcon.Information)
        Catch ex As Exception
            MessageBox.Show("Error exporting drive report: " & ex.Message)
        End Try
    End Sub

End Class
